@@ -244,8 +244,14 @@ class Detector(Analysis):
         # Extract method name from kwargs
         method = kwargs.get('method', 'ampa')
         if supervised:
+            import matplotlib
+            if sys.platform == "win32":
+                matplotlib.use('Qt4Agg')
+                matplotlib.rcParams['backend.qt4'] = 'PySide'
+            elif sys.platform == "linux2":
+                matplotlib.use('TkAgg')
+            matplotlib.rcParams['interactive'] = True
             import matplotlib.pyplot as pl
-            pl.ion()
         for record in records:
             self.on_notify("Processing %s... " % record.filename)
             record.detect(alg, **kwargs)
@@ -263,7 +269,6 @@ class Detector(Analysis):
                     supervised = False
                     pl.close('all')
         if supervised:
-            pl.ioff()
             pl.close('all')
 
     def _supervise_events(self, record, takanami=True, show_len=5.0,
@@ -324,12 +329,18 @@ class Picker(Analysis):
         # Extract method name from kwargs
         method = kwargs.get('method', 'ampa')
         if supervised:
+            import matplotlib
+            if sys.platform == "win32":
+                matplotlib.use('Qt4Agg')
+                matplotlib.rcParams['backend.qt4'] = 'PySide'
+            elif sys.platform == "linux2":
+                matplotlib.use('TkAgg')
+            matplotlib.rcParams['interactive'] = True
             import matplotlib.pyplot as pl
-            pl.ion()
         for record in records:
             self.on_notify("Processing %s... " % record.filename)
             if supervised:
-                record.detect(alg, threshold=0.0, **kwargs)
+                record.detect(alg, **kwargs)
                 self.on_notify("Done\n")
                 # Sort events
                 key, reverse = self._sort_keys.get('vd', ('cf_value', True))
@@ -346,7 +357,6 @@ class Picker(Analysis):
                 self.on_notify("Done\n")
                 draw_events_table(record, method)
         if supervised:
-            pl.ioff()
             pl.close('all')
 
     def _supervise_events(self, record, takanami=True, show_len=5.0,
@@ -369,8 +379,8 @@ class Picker(Analysis):
             event = record.events[i]
             self.on_notify("Showing event no. %i of %i\n" %
                              (i + 1, len(record.events)))
-            record.plot_signal(t_start=event.time - show_len,
-                               t_end=event.time + show_len,
+            record.plot_signal(t_start=(event.time / record.fs) - show_len,
+                               t_end=(event.time / record.fs) + show_len,
                                num=1,
                                show_cf=show_cf,
                                show_specgram=show_specgram,
@@ -397,7 +407,8 @@ def analysis(**kwargs):
     Performs event detection if parameter 'threshold' is not None, otherwise
     performs event picking.
     """
-    if 'threshold' in kwargs:
+    threshold = kwargs.get('threshold', None)
+    if threshold is not None:
         task = Detector()
     else:
         task = Picker()
